# -*- coding: utf-8 -*-
""" db_database

	Defined the tables for your applications.
	Initialized the web2py-dbui plugins
	
	$Id$
	
"""
from datetime import datetime
from gluon.tools import PluginManager

#-------------------------------------------------------------------------------
#
# web2py-dbui plugin parameters
#
#-------------------------------------------------------------------------------
plugins = PluginManager()
plugins.dbui.script_path = 'static/scripts'		# js scripts for your applications
#plugins.dbui.page_view = 'plugin_dbui.html'

T.lazy = False		# immediate translation
#-------------------------------------------------------------------------------
#
# connection to the database
#
#-------------------------------------------------------------------------------
db = DAL('sqlite://storage.sqlite')       # if not, use SQLite or other DB

#-------------------------------------------------------------------------------
#
# Categories tables
#
#-------------------------------------------------------------------------------
db.define_table("categories_aeres",
	Field("code", "string", notnull=True),
	Field("definition", "text", notnull=True))

#-------------------------------------------------------------------------------
#
# Collaboration table
#
#-------------------------------------------------------------------------------
db.define_table("collaborations",
	Field("collaboration", "string", notnull=True))

#-------------------------------------------------------------------------------
#
# Countries table
#
#-------------------------------------------------------------------------------
db.define_table("countries",
	Field("country", "string", notnull=True),
	Field("abbreviation", "string", notnull=True))

#-------------------------------------------------------------------------------
#
# Projects table
#
#-------------------------------------------------------------------------------
db.define_table("projects",
	Field("project", "string", notnull=True))

#-------------------------------------------------------------------------------
#
# Publishers table
#
#-------------------------------------------------------------------------------
db.define_table("publishers",
	Field("publisher", "string", notnull=True),
	Field("abbreviation", "string", notnull=True))

#-------------------------------------------------------------------------------
#
# Reports table
#
#-------------------------------------------------------------------------------
db.define_table("reports",
	Field("type", "string", notnull=True))

#-------------------------------------------------------------------------------
#
# Teams table
#
#-------------------------------------------------------------------------------
db.define_table("teams",
	Field("team", "string", notnull=True))

#-------------------------------------------------------------------------------
#
# Publications table
# the main table of this application
# Create at the end since its depends on the other tables
#
#-------------------------------------------------------------------------------
#
# Regular expression defining authors, authors_cppm and speaker
#
#match_authors = \
#IS_MATCH(r'(((, )?([A-Z]\.(-[A-Z]\.)?)( [A-Z][a-z]+)+( et al.)?)+)')
#
#match_authors_cppm = \
#IS_MATCH(r'((, )?([A-Z]\.(-[A-Z]\.)?)( [A-Z][a-z]+)+)+')

#match_report_numbers = \
#IS_MATCH(r'')

#match_speaker = IS_MATCH(r'[A-Z]\.(-[A-Z]\.)?( [A-Z][a-z]+)+')

year = datetime.now().year

#
# tooltips
#
tp_authors = \
"""List of authors separated by commma: J. Doe, P.-Y. Smith
For large collaboration the first author followed by et al.: J. Doe et al."""

tp_authors_cppm = \
"""List of authors separated by comma: P.-Y. Doe, J. Smith"""

tr_report_numbers = \
"""List of report identifier separated by comma: 
LHCb-PROC-2008-04, arXiv:0906.1516 """
 
tp_speaker = \
"""The name of the speaker: P.-Y. Smith"""

#
# the table
#
db.define_table("publications",
	Field("title", "text", notnull=True),
	Field("authors", "string", notnull=True, comment=tp_authors),
	Field("id_collaborations", db.collaborations, default=1, label="Collaboration"),
	Field("id_publishers", db.publishers, default=1,  label="Publisher"),
	Field("year", "integer", notnull=True, default=year, requires=IS_INT_IN_RANGE(1900, year+1)),
	Field("doi", "string"),
	Field("volume", "integer", requires=IS_EMPTY_OR(IS_INT_IN_RANGE(1, None))),
	Field("first_page", "integer", requires=IS_EMPTY_OR(IS_INT_IN_RANGE(1, None))),
	Field("last_page", "integer", requires=IS_EMPTY_OR(IS_INT_IN_RANGE(1, None))),
	Field("e_print", "string", requires=IS_EMPTY_OR(IS_URL())),
	Field("conference_title", "text", label='Title'),
	Field("conference_url", "string", label='url', requires=IS_EMPTY_OR(IS_URL())),
	Field("conference_start", "date", label='Start date'),
	Field("conference_end", "date", label='End date'),
	Field("conference_town", "string", label='Town'),
	Field("id_countries", db.countries, default=1, label='Country'),
	Field("conference_speaker", "string", label='Speaker', comment=tp_speaker),
	Field("report_numbers", "string", comment=tr_report_numbers),
	Field("id_reports", db.reports, default=1, label="Report type"),
	Field("authors_cppm", "text", notnull=True, comment=tp_authors_cppm),
	Field("id_teams", db.teams, default=1, label='Team'),
	Field("id_projects", db.projects, default=1, label='Projects'),
	Field("id_categories_aeres", db.categories_aeres, default=1, label='AERES'))

#
# define foreign keys
#
db.publications.id_categories_aeres.requires = \
IS_IN_DB(db, 'categories_aeres.id', 'categories_aeres.code')

db.publications.id_collaborations.requires = \
IS_IN_DB(db, 'collaborations.id', 'collaborations.collaboration')

db.publications.id_countries.requires = \
IS_IN_DB(db, 'countries.id', 'countries.country')

db.publications.id_publishers.requires = \
IS_IN_DB(db, 'publishers.id', 'publishers.abbreviation')

db.publications.id_projects.requires = \
IS_IN_DB(db, 'projects.id', 'projects.project')

db.publications.id_reports.requires = \
IS_IN_DB(db, 'reports.id', 'reports.type')

db.publications.id_teams.requires = \
IS_IN_DB(db, 'teams.id', 'teams.team')
