""" $Id$
	Author: R. Le Gac
"""

__version__ = "$Revision$"


from gluon.validators import IS_IN_DB

K_TABLE = "k_table"
K_FIELD = "k_field"
K_KEY = "k_key"
 
class ForeignField(dict):
	
	def __init__(self, db):
		""" Scan the database model to identify foreign key,
		Store the pointing table and field.
		
		"""

		for table in db.tables:
			fields = [db[table][el] for el in db[table].fields]
			
			for field in fields:
				#
				# FOREIGN FIELD
				#
				# The reference to the foreign table is defined in the
				# type: "reference foreignTable".
				# The foreign table and the associated column are also
				# defined in the validator IS_IN_DB.
				#
				if field.type.startswith("reference"):
				
					validators = field.requires
					if not isinstance(validators, (list, tuple)):
						validators = [field.requires]
				
					for vdt in validators:
						if isinstance(vdt, IS_IN_DB):
							
							if table not in self:
								self[table] = {}
								
							self[table][field.name] = {}
							self[table][field.name][K_TABLE] = vdt.ktable
							self[table][field.name][K_FIELD] = vdt.ks[0]
							self[table][field.name][K_KEY] = vdt.ks[1]
							
	
	def is_foreign_field(self, table, field):
		""" Return true is the table.field is a foreign key.
		
		"""
		if table in self:
			return field in self[table]
		
		else:
			return False
		
		
	def is_table_with_foreign_fields(self, table):
		return (True if table in self else False)
	
	 
	def get_foreign_data(self, table, field):
		""" Return a tuple containing the pointing table, the pointing field 
		and key for the join:
		
			table.field --> k_table.k_field
			table.field == k_table.k_key
			
		Otherwise return None.
		
		"""
		if self.is_foreign_field(table, field):
			di = self[table][field]
			return (di[K_TABLE], di[K_FIELD], di[K_KEY])
		
		else:
			return None

