/**
 * A pre-configured combobox reading its data in the database.
 * Design to work with the class DbSvc on the server side.
 * 
 * MANDATORY PROPERTIES:
 * 		- model   		model to configure the object provide by the server
 * 		- displayField	field of the table shown in the combobox
 * 		- valueField	field of the table return by the combobox 
 * 
 * All configuration properties of Ext.form.ComboBox are understood.
 * 
 * @extends Ext.form.ComboBox 
 * @author $Author$
 * @version $Id$
 *
 */
Ext.namespace('App.form');

App.form.ComboBox = Ext.extend(Ext.form.ComboBox, {

	/**
	 * @cfg {Object} model Object to configure the widget. 
	 * It is provided by the server and contains the following keys:
	 * 	{ store: {
	 * 		table: 'x', 
	 * 		dbFields: [(table1, field1), (table1, field2)],
	 * 		fields: [field1, field2], 
	 * 		debug: false}
	 * } 
	 */
	model: null,
	
	/**
	 * Predefined setting
	 *
	 */
	mode:'remote',
	editable: false,
	selectOnFocus: true,
	triggerAction: 'all',
	typeAhead: true,
	
	/**
	 * private method require by the ExtJs component model
	 */	
	initComponent: function(){

		// defined the empty text from the field label
		if(this.fieldLabel && !this.emptyText){
			this.emptyText = "Select a "+this.fieldLabel+" ...";	
		}

		// setup the store if not defined by the user
		// the autoLoad property set at true is mandatory to
		// set a value when the combobox is not yet expend
		if (!this.store) {
			
			this.store = new App.data.JsonStore({
				url: App.dburl,
				model: this.model.store,
				debug: App.debug,
				sortInfo: {field: this.displayField},
				autoLoad: true,
			});
		}

		// construct the underlying class. DON'T MOVE
		App.form.ComboBox.superclass.initComponent.call(this);
		
		// This few lines are required to set a value 
		// when the combobox is not yet expend
		this.store.on('load', function(){
			this.setValue(this.getValue());
		}, this);
	},
});

Ext.reg('xcombobox', App.form.ComboBox);
