/**
 * The FormPanel class is a configured version of the Ext.form.formPanel.
 * The panel contains the form and additional button: Clear, Ok, Update and
 * Delete. Only two buttons are shown simultaneously: Clear+Ok or Clear+Update
 * or Clear+Delete. The methods showButton.. allow to choose the setting.
 * 
 * Buttons are visible via the properties of the object to ease the 
 * implementation of handlers: form.buttonCreate.on("click",....)
 * 
 * Record can be load using formPanel.getForm().loadRecord(record).
 * Values can be retrieved using formPanel.getForm().getFieldValues().
 * 
 * See also Ext.form.FormPanel and Ext.form.BasicPanel 
 * 
 * The type of this component is xform.
 * 
 * @extends Ext.form.FormPanel
 * @version $Id$
 * 
 */
Ext.namespace('App.form');

App.form.FormPanel = Ext.extend(Ext.form.FormPanel, {

	/**
	 * Predefined setting
	 */
	autoScroll: true,
	bodyStyle: 'padding:5px 5px 0',
	buttons: [{
		text: 'Clear',
		ref: '../buttonClear',
	}, {
		text: 'Create',
		ref: '../buttonCreate'
	}, {
		text: 'Update',
		ref: '../buttonUpdate',
		hidden: true
	}, {
		text: 'Delete',
		ref: '../buttonDelete',
		hidden: true
	}],
	defaults: {anchor: '100%'},
	defaultType: 'textfield',
	frame: true,
	
	/**
	 * private method require by the ExtJs component model
	 */	
	initComponent: function(){
		
		// construct the underlying class. DON'T MOVE
		App.form.FormPanel.superclass.initComponent.call(this);
		
		// reset the form
		this.buttonClear.on('click', function(){this.reset();}, this.getForm());
	},

	/**
	 * Helper function to enable/disable all fields of the form
	 * @param {Object} bool
	 */
	setFieldsDisable: function(bool){
		var form = this.getForm();
		for (var i = 0; i < form.items.length; i++) {
			form.items.itemAt(i).setDisabled(bool);
		}
	},
	
	/**
	 * Show the delete button and hide the others
	 */
	showButtonDelete: function(){
		this.buttonDelete.show();
		this.buttonCreate.hide();
		this.buttonUpdate.hide();
	},

	/**
	 * Show the Create button and hide the others
	 */
	showButtonCreate: function(){
		this.buttonDelete.hide();
		this.buttonCreate.show();
		this.buttonUpdate.hide();
	},
	
	/**
	 * Show the Update button and hide the others
	 */
	showButtonUpdate: function(){
		this.buttonDelete.hide();
		this.buttonCreate.hide();
		this.buttonUpdate.show();
	},
});

Ext.reg('xform', App.form.FormPanel);
