/**
 * A FormPanel to submit new entry in the database.
 * Design to work with the class HttpDb on the server side.
 * 
 * MANDATORY PROPERTIES:
 * 		- url     		the url of the server
 * 		- table   		the name of the database table
 * 
 * All configuration properties of Ext.form.FormPanel are understood.
 * 
 * The type of this component is xentry.
 * 
 * NOTE: the javascript file containing App.form.FormPanel has to
 * loaded before this one. It is why it is name appform2.
 * 
 * @extends Ext.form.FormPanel 
 * @author $Author$
 * @version $Id$
 *
 */

Ext.namespace('App.form');

App.form.EntryFormPanel = Ext.extend(App.form.FormPanel, {

	/**
	 * @cfg {Object} model Object to configure the widget 
	 * for a table of the database. It is provided by the server 
	 * and contains the following keys:
	 * 	{
	 * 		item: [...], 
	 * 		table: 'x', 
	 * 		title: 'y', 
	 * 		xtype: 'xentry'
	 * } 
	 */
	model: null,
	
	/**
	 * private method require by the ExtJs component model
	 */	
	initComponent: function(){

		if (!this.model){
			throw new Error("the property model is missing !!!")
		}

		// define the item and the url
		// NOTE: it is mandatory to defined the url here.
		this.items = this.model.items;
		this.url = App.dburl;

		App.form.EntryFormPanel.superclass.initComponent.call(this);
		this.buttonCreate.on("click", this.onSubmit, this);
		
		// Add handler to display tool tip for each field
		// Require the configuration parameter tipText.
		var fields = this.findByType('field');
		for (var i = 0; i < fields.length; i++){
			var field = fields[i];
			if (field.tipText){
				field.on('render', function(c){
				    new Ext.ToolTip({
				        target: c.getEl(),
						title: c.fieldLabel,
				        anchor: 'left',
				        trackMouse: false,
				        html: Ext.util.Format.htmlEncode(c.tipText),
				    });
				});
			}
		}
	},

	/**
	 * Private handler to submit values in the database
	 */		
	onSubmit: function(){

		this.getForm().submit({
			clientValidation: true,
			url: this.url,
			method: 'POST',
			params: {
				'debug': App.debug,
				'table': this.model.table,
				'xaction': 'create'
			},
			reset: true,
			waitMsg: 'Saving Record...',			
			failure: function(form, action){
				if (action.response) {
					if (action.response.status != 200) {
						Ext.MessageBox.alert('Error', action.response.responseText);
					}
				}
			},
		});
	},
});

Ext.reg('xentry', App.form.EntryFormPanel);
