/**
 * The paging bottom bar plugin
 * The ptype of this component is pGridPaging.
 *  
 * @version $Id$
 * 
 */
Ext.namespace('App.grid');

App.grid.Paging = Ext.extend(Object, {

	/**
	 * Private parameter identifying the type of plugin
	 */
	ptype: 'pGridPaging',

	/**
	 * Plugin intialisation
	 */
	init: function(grid){

		grid.pagingInitialized = false;
		
		// associate the bbar to the grid store
		var bbar = grid.getBottomToolbar();
		bbar.bindStore(grid.store);

		// add the slider and the export button
		bbar.add('-', 
				 'Rows per page', 
				 {
				 	xtype: 'slider',
					plugins: new Ext.slider.Tip(),
					listeners: {changecomplete: this.onChangePageSize,
								scope: bbar},
					minValue: 1,
					width: 100,
				 }, 
				 '->',
				 {
				 	xtype: 'button',
					text: 'Export to CSV',
					listeners: {click: this.onExport},	
				 }
		);
		
		bbar.show();
		
		// NOTE: when this plugin is used, the grid load the store
		// with the first row only. The results contains the total
		// number of records in the store. We used it to initialized
		// properly the slider. 
		grid.store.on('load', this.onStoreLoad, grid);
		
	},
	
	/**
	 * Handler to change the number of rows per page
	 */
	onChangePageSize: function(slider, newValue, thumb){
		var bbar = this;
		bbar.pageSize = newValue;
		bbar.moveFirst();
	},
	
	/**
	 * Handler to export the grid content as a CSV file
	 */
	onExport: function(button ,event){
		Ext.Msg.alert('Warning', 'Functionality not yet implemented');
	},
	
	/**
	 * Handler to tune the number of rows per page and the number of page
	 */
	onStoreLoad: function(store, records, options){

		var grid = this;
		if(grid.pagingInitialized)
			return;
		
		grid.pagingInitialized = true;
		
		var bbar = grid.getBottomToolbar();
		var slider = bbar.findByType('slider')[0];
		
		// NOTE: the number of row which visible in the browser
		// can be obtained having a look to the DOM tree finding
		// CSS component name x-grid3-cell-inner. Then by comparing
		// the innerHeight of the browser window and the height of the
		// cell we can compute the number of rows ? For later !! 
		var nRows = 10
		
		slider.maxValue = store.totalLength;
		slider.setValue(nRows);
		
		bbar.pageSize = nRows;
		bbar.moveFirst();
	},
	
});

Ext.preg('pGridPaging', App.grid.Paging);
