/**
 * The row editor context menu plugin
 *
 * Display the context menu when the user right click on a row.
 * The content of the menu allows to manipulate the App.grid.RowEditor
 * The RowEditor is instantiated if not already create.
 * 
 * The ptype of this component is pGridRowEditorContextMenu.
 *
 * @version $Id$
 * 
 */

Ext.namespace('App.grid');

App.grid.RowEditorContextMenu = Ext.extend(Object, {

	/**
	 * Private parameter identifying the type of plugin
	 */
	ptype: 'pGridRowEditorContextMenu',
	
	/**
	 * Plugin intialisation
	 * @param {Object} grid
	 */
	init: function(grid){
				
		var menu = new Ext.menu.Menu();
		
		// create and initialize the underlying RowEditor		
		if (!grid.editor){
			grid.editor = new App.grid.RowEditor({
				formModel: grid.model.formModel,
				table: grid.model.table,
			});
			
			grid.editor.init(grid);
		}

		grid.addListener('containercontextmenu', this.onContainerContextMenu, menu);
		grid.addListener('headercontextmenu', this.onHeaderContextMenu, menu);
		grid.addListener('rowcontextmenu', this.onRowContextMenu, menu);
		
		menu.add({
            text: 'Add',
            iconCls: 'silk-add',
            handler: grid.editor.onAddRow,
			scope: grid.editor
        }, '-', {
            text: 'Delete',
            iconCls: 'silk-delete',
            handler: grid.editor.onDeleteRow,
			scope: grid.editor
		}, '-', {
			text: 'Duplicate',
            iconCls: 'silk-clone',
            handler: grid.editor.onDuplicateRow,
			scope: grid.editor
		}, {
            text: 'Update',
            iconCls: 'silk-update',
            handler: grid.editor.onEditRow,
			scope: grid.editor
		}, '-', {
            text: 'View',
            iconCls: 'silk-view',
            handler: grid.editor.onViewRow,
			scope: grid.editor
        });
	},
	
	/**
	 * Handler displaying the row context menu in an empty grid
	 */
	onContainerContextMenu: function(grid, event){
		var menu = this;
		
		event.stopEvent();
		menu.showAt(event.getXY());
		
	},
	/**
	 * Handler displaying the context menu in the header
	 * Nothing is display in that case.
	 */
	onHeaderContextMenu: function(grid, columIndex, event){
		event.stopEvent();
	},
	/**
	 * handler displaying the row context menu
	 * The scope use by the handler is defined by the caller.
	 * It has to be the equal to the menu object.
	 */
	onRowContextMenu: function(grid, rowIndex, event){
		
		var menu = this;
		
		event.stopEvent();
		grid.selModel.selectRow(rowIndex);		
		menu.showAt(event.getXY());

	},

});

Ext.preg('pGridRowEditorContextMenu', App.grid.RowEditorContextMenu);
