/**
 * Plugin InTreeGrid.
 * 
 * The App.Viewport contains a tree and a tab panels.
 * This plugin add a topNode in the tree which contains child.
 * When a child is clicked a new tab appears in the tab panel.
 * 
 * The name of the child nodes are defined by the property 'nodes'.
 * For example the name of the tables for a database application.
 * 
 * The tab contains a App.grid.GridPanel panel. 
 * Its configuration is retrieve from the server.
 * the property wdgCfg allow to add additional configuration property
 * to the grid like plugins.
 *
 * The ptype of this component is pInTreeGrid.
 *  
 * MANDATORY PROPERTIES:
 * 		- models
 * 		- topNodeName
 * 		- nodes
 * 
 * @author legac
 * @extend App.viewport.InTreePanelBase
 * @version $Id$
 * 
 */
Ext.namespace('App.viewport');

App.viewport.InTreePanelGrid = Ext.extend(App.viewport.InTreePanelBase, {

	/**
	 * private function to instantiate the grid and to add it to the tab
	 * 
	 * @param {Object} container
	 * @param {Object} component
	 * @param {Object} index
	 */
	addWdg: function(container, component, index){

		// protection -- add widget when we are concern !				
		if (this.getTopNodeNameFromId(component.id) != this.topNodeName){
			return;
		}
		
		// get the name of the table from the tab id
		var table = this.getNodeNameFromId(component.id);
		
		// Ask the server the widget configuration and create it
		cfgSvc.getGridModel(table, function(provider,response){
		
			var cfg = response.result;
			var wdg = Ext.ComponentMgr.create(cfg);		
			
			component.add(wdg);
			component.doLayout();
			
		}, this);
	},
});
Ext.preg('pInTreeGrid', App.viewport.InTreePanelGrid);
